﻿Option Strict On
Option Explicit On

Imports Telerik.Web.UI

Partial Class master_NavMenu
    Inherits BaseMasterPage

    Protected _user As AuditID

    Protected ReadOnly Property user() As AuditID
        Get
            If NotSet(_user) Then
                _user = Me.proj.CurrentUser
            End If
            Return _user
        End Get
    End Property

    Public Property VirtualRoot() As String
        Get
            Return CStr(ViewState("vr"))
        End Get
        Set(ByVal value As String)
            ViewState("vr") = value
        End Set
    End Property

#Region "Page Events"

    Protected Sub Page_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
        If Me.IsPostBack Then
            LoadPopup(Me.ActivePopup)       'If there's an active popup, reload it (need to remove when possible!)
        End If
    End Sub

#End Region

#Region "Master page required overrides"

    Public Overrides Sub SetPageTitle(ByVal Title As String, ByVal ParamArray args() As Object)
        lblPageTitle.Text = StrFormat(Title, args)
    End Sub

    ''' <summary>
    ''' allows full control path now ~/xxx/yyy.ascx
    ''' </summary>
    ''' <param name="PopupName">either simply a name (xxxx) of a control in ~/ModalPopups/xxxx.ascx or a complete control vpath</param>
    ''' <param name="Args"></param>
    ''' <param name="Width"></param>
    ''' <param name="Height"></param>
    ''' <remarks></remarks>
    Public Overrides Sub SetPopup(ByVal PopupName As String, ByVal Args As String, Optional ByVal Width As Integer = 700, Optional ByVal Height As Integer = 550)
        LoadPopup(PopupName, Args, Width, Height)
        Me.Popup_Extender.Show()
        Me.ActivePopup = PopupName
        Me.ActivePopupArgs = Args
    End Sub

    Public Overrides Property PopupArgs() As String
        Get
            Return Me.ActivePopupArgs
        End Get
        Set(ByVal value As String)
            Me.ActivePopupArgs = value
        End Set
    End Property

    Public Overrides Property PopupClientCloseButtonVisible() As Boolean
        Get
            Return cmdClose.Visible
        End Get
        Set(ByVal value As Boolean)
            cmdClose.Visible = value
        End Set
    End Property

    Public Overrides ReadOnly Property ActivePopupDialog() As ModalDialog
        Get
            Return CType(ph.Controls(0), ModalDialog)
        End Get
    End Property

#End Region

#Region "Popup Support"

    Private Sub LoadPopup(ByVal PopupName As String, Optional ByVal sArgs As String = Nothing, Optional ByVal Width As Integer = 700, Optional ByVal Height As Integer = 550)
        If Not String.IsNullOrEmpty(PopupName) Then
            Popup_Panel.Width = New Unit(Width & "px")
            Popup_Panel.Height = New Unit(Height & "px")
            Dim sCTLpath As String
            If PopupName.StartsWith("~") Then
                sCTLpath = PopupName                'allow full path
            Else
                sCTLpath = String.Format("~/ModalPopups/{0}.ascx", PopupName)
            End If
            Dim ctl As Control = LoadControl(sCTLpath)
            ctl.ID = "Popup1"
            ph.Controls.Clear()
            ph.Controls.Add(ctl)

            Dim dlg As ModalDialog = CType(ctl, ModalDialog)
            AddHandler dlg.DialogComplete, AddressOf DialogComplete
            If Not IsNothing(sArgs) Then
                dlg.OnBeginPopup(sArgs)
            End If
            Me.Popup_UpdatePanel.Update()
        End If
    End Sub

    Private Sub DialogComplete(ByVal sender As Object, ByVal e As PopupCompleteEventArgs)
		'Logit("ModalDialogHolder.DialogComplete()")
		OnPopupClose(sender, e)                         'raise event to Page
        ph.Controls.Clear()
        Me.ActivePopup = ""
        Me.Popup_Extender.Hide()
    End Sub

    Public Property ActivePopup() As String
        Get
            Return CStr(ViewState("ActivePopup"))
        End Get
        Set(ByVal value As String)
            ViewState("ActivePopup") = value
        End Set
    End Property

    Public Property ActivePopupArgs() As String
        Get
            Return CStr(ViewState("ActivePopupArgs"))
        End Get
        Set(ByVal value As String)
            ViewState("ActivePopupArgs") = value
        End Set
    End Property

#End Region

#Region "Toolbar"

    Public Overrides ReadOnly Property Toolbar() As Telerik.Web.UI.RadToolBar
        Get
            Return Nothing
        End Get
    End Property

#End Region

#Region "Init"

    Protected Sub litYear_Init(ByVal sender As Object, ByVal e As System.EventArgs) Handles litYear.Init
        litYear.Text = Now.Year.ToString
    End Sub

#End Region

#Region "Load"

    Protected Sub icoAltConfigWarning_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles icoAltConfigWarning.Load
        If Not IsPostBack Then
			'
			' show the warning icon if host is LocalHost and connection.host_name() is one of the known DB servers
			'
			Dim cn = Me.proj.Connection
			Dim dbServer = cn.GetScalarString("select upper(@@serverName)")

            If Request.Url.ToString.ToLower.IndexOf("//localhost") > -1 Then
				If isProdServer(dbServer) OrElse isTestServer(dbServer) Then
					icoAltConfigWarning.Visible = True
					icoAltConfigWarning.ToolTip = "WARNING: web server is localhost, but DB SERVER IS " + dbServer
				End If
			End If
        End If
    End Sub

    Protected Sub imgLogo_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles imgLogo.Load
        Dim tt As String
        tt = "Click to Navigate to Nucleus Home"
        If Not Page.IsPostBack Then
            imgLogo.ToolTip = tt
        End If
    End Sub

    Protected Sub lblProjectID_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles lblProjectID.Load
		lblProjectID.Text = Me.proj.ProjectID
		lblProjectID.ToolTip = Me.proj.Info.ProjectName
	End Sub

    Protected Sub hlHomeLink_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles hlHomeLink.Load
		hlHomeLink.NavigateUrl = Me.proj.NucleusHomeURL
	End Sub

    'Private Sub hlHelpPage_Load(sender As Object, e As EventArgs) Handles hlHelpPage.Load
    '    If user.IsExternalUser Then
    '        hlHelpPage.Visible = False
    '    Else
    '        hlHelpPage.NavigateUrl = ProjMP.NucleusHomeURL + "?tab=Help"
    '    End If
    'End Sub

    Protected Sub imgProject_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles imgProject.Load
		If Me.proj.ProjectID <> "DEV" Then
			Dim projImgURL = Me.proj.Info.projectImageUrl
			If IsSet(projImgURL) Then
				imgProject.ImageUrl = projImgURL.Replace("VFile.axd", "projectHome/Gallery/VFile.axd")      'using "projectHome/Gallery/VFile.axd" means don't log in ActLog because it's excluded via web.config appSettings
			End If
		End If
	End Sub

#End Region

#Region "Pre-Render"

    Protected Sub cssThemeLink1_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles cssThemeLink1.PreRender
        cssThemeLink1.Href = Me.user.CustomizeTheme(cssThemeLink1.Href)
    End Sub

    Protected Sub cssThemeLink2_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles cssThemeLink2.PreRender
        cssThemeLink2.Href = Me.user.CustomizeTheme(cssThemeLink2.Href)
    End Sub

    Protected Sub litLogIcon_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles litLogIcon.PreRender
        If Not IsPostBack Then
            If Me.user.IsExternalUser Then
                litLogIcon.Text = ""
            Else
                litLogIcon.Text = "<div id='logIcon' title='click to display the debug log' onclick=""$logger.dialog('open');ScrollToEndOfLogger();""></div>"
            End If
        End If
    End Sub

    Protected Sub Page_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.PreRender
        Dim proj = ProjMP
        Dim user = proj.CurrentUser
        '
        ' fill in page info fields
        '
        Dim pagePath = Server.MapPath(Request.CurrentExecutionFilePath)
        litPageName.Text = IO.Path.GetFileNameWithoutExtension(pagePath)
        lblPageVer.Text = Fluor.WebCommon.Core.pageVersion()
        'Logit("lblPageVer.ToolTip={0}", lblPageVer.ToolTip)

        Dim sessionID = IIfS(Session.IsNewSession, "*", "") + Session.SessionID

		Dim requiredRole = ""
		Try
			If TypeOf Page Is ProjectPage Then
				requiredRole = "Required Role: " + CType(Page, ProjectPage).RequiredRole()
			End If
		Catch ex As Exception
			curActLogRec.AddError(ex, "could not get Required Role for web page {0}", Request.AppRelativeCurrentExecutionFilePath)
			requiredRole = "Required Role: (error)"
		End Try

		lblPageVer.Attributes("title") = Replace(user.InfoLine, "|", vbCrLf) + vbCrLf + "Session: " + sessionID
		'
		' Fill in the 2 lines of USER info.
		' for EXTERNAL users, make the top one the username and the bottom one a LOGOUT link
		'
		If user.IsExternalUser Then
            litUser1.Text = user.Username
            litUser2.Text = "<span class='clickable' style='font: normal 7pt verdana' title='click to log out' onclick='logout();'>Logout</span>"
        Else
            With SplitInTwo(user.Username, "\")
                litUser1.Text = .LeftSide
                litUser2.Text = .RightSide
                lblClockCountDown.Style("display") = "none"
                lblTimeCountDown.Style("display") = "none"
                litCountdownBreak.Visible = False
            End With
        End If

    End Sub


#End Region

#Region "One-Shot Notification"

    Protected Sub oneShotNotification_PreRender(ByVal sender As Object, ByVal e As System.EventArgs) Handles oneShotNotification.PreRender
        AddHandler Me.Page.PreRenderComplete, AddressOf page_PreRenderComplete
    End Sub

    Protected Sub page_PreRenderComplete(ByVal sender As Object, ByVal e As System.EventArgs)
        '
        ' the session object "ActiveNotificationTitle" is used whenever a page wants to redirect
        ' the client, and when the "new" page loads, wants to show a message.
        ' using session makes it survive the redirect.
        ' all page loads look for this item and if found, display it and remove it.
        '
        Dim title = CStr(Session("ActiveNotificationTitle"))
        Session.Remove("ActiveNotificationTitle")

        Dim text = CStr(Session("ActiveNotificationText"))
        Session.Remove("ActiveNotificationText")

        If Present(title) OrElse Present(text) Then
			'Logit("ActiveNotificationTitle={0}, ActiveNotificationText={1}", title, text)
			With oneShotNotification
                .Title = title
                .Text = text
                .Enabled = True
                .Visible = True
                .VisibleOnPageLoad = True
            End With
        End If
    End Sub

#End Region

    Protected Function GetKnownVersionsScript() As String

        '	var _currentDBver = null;
        '	var _currentCfgVer = null;

        Dim x = Me.proj.Connection.GetScalarPair(Of Integer, Integer)("SELECT top 1 [ver],[cfgVer] FROM version")
        Return StrFormat("_currentDBver={0}; _currentCfgVer={1}", x.value1, x.value2)

    End Function

    Protected Sub pueProjectLogoTopRight_PreRender(sender As Object, e As EventArgs) Handles pueProjectLogoTopRight.PreRender
        With proj.CurrentUser
            pueProjectLogoTopRight.Visible = .IsAdmin
            If pueProjectLogoTopRight.Visible Then
                Dim encodedVpath = BinaryHelper.munge("/config/project/pictures/project.jpg")
                pueProjectLogoTopRight.PopupEditURL = StrFormat("~/Dialogs/tags/SingleAttachmentSelector.aspx?path={0}&projID={1}&limit=1&public=1", encodedVpath, ProjMP.ProjID)
            End If
        End With
    End Sub

	Public Overrides Sub RebindMenu()
		Me.Session.Remove("menu_table")        'release cached item
		Me.NavMenu.Nodes.Clear()
		Me.NavMenu.RebuildMenu()
	End Sub

    Private Sub btnNewSession_Click(sender As Object, e As EventArgs) Handles btnNewSession.Click
        HttpContext.Current.Session.Abandon()
        Response.Redirect("~/projectHome.aspx", True)
    End Sub
End Class



